from setuptools import setup, find_packages

setup(
    name='django-cms-smartsnippets',
    version='0.1',
    description='Parametrizable Django CMS snippets.',
    author='Sever Banesiu',
    author_email='banesiu.sever@gmail.com',
    packages=find_packages(),
    include_package_data=True,
)
